package com.cedarsoft.business;

import com.google.common.collect.HashMultimap;
import com.google.common.collect.Multimap;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

import java.util.Collection;
import java.util.Collections;

/**
 * Abstract implementation of a code provider.
 */
public abstract class AbstractCodesProvider {
  @NotNull
  protected final Multimap<String, String> name2codes = new HashMultimap<String, String>();
  @NotNull
  protected final Multimap<String, String> code2names = new HashMultimap<String, String>();

  /**
   * Returns the codes for the given name
   *
   * @param name the name
   * @return a collection of codes
   */
  @NotNull
  @NonNls
  public Collection<String> getCodes( @NotNull @NonNls String name ) {
    Collection<String> postalCodes = name2codes.get( name );
    if ( postalCodes == null || postalCodes.isEmpty() ) {
      throw new IllegalArgumentException( "No postal codes found for " + name );
    }
    return Collections.unmodifiableCollection( postalCodes );
  }

  /**
   * Returns the names for the given code
   *
   * @param code the code
   * @return the names
   */
  @NotNull
  @NonNls
  public Collection<String> getNames( @NotNull @NonNls String code ) {
    Collection<String> cityNames = code2names.get( code );
    if ( cityNames == null || cityNames.isEmpty() ) {
      throw new IllegalArgumentException( "No city found for " + code );
    }
    return cityNames;
  }
}
