package com.cedarsoft.business.contact;

import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

import java.util.Collection;

/**
 * Provides codes for one country (e.g. postal or area codes).
 */
public interface CityCodeProvider {
  /**
   * Returns the country code this provider has codes for
   *
   * @return the country code
   */
  @NotNull
  @NonNls
  String getCountryCode();

  /**
   * Returns the codes for the given city. This method returns a collections
   * with at least one entry.
   *
   * @param city the city
   * @return the codes for the city
   */
  @NotNull
  @NonNls
  Collection<String> getCodes( @NotNull @NonNls String city );

  /**
   * Returns the stored city names for the given code.
   * This method returns a collections
   * with at least one entry.
   *
   * @param code the code
   * @return the city names
   */
  @NotNull
  @NonNls
  Collection<String> getCityNames( @NotNull @NonNls String code );
}