package com.cedarsoft.business.contact;

import org.jetbrains.annotations.NotNull;

import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

/**
 * Contains several city code providers.
 */
public class CityCodeProvidersRegistry {
  /**
   * The key is the ISO2 for the country
   */
  @NotNull
  private final Map<String, CityCodeProvider> codeProviders = new HashMap<String, CityCodeProvider>();


  /**
   * Adds an additional provider
   *
   * @param provider the provider that is registered
   */
  public void add( @NotNull CityCodeProvider provider ) {
    codeProviders.put( provider.getCountryCode(), provider );
  }

  /**
   * Returns the provider for the given locale
   *
   * @param locale the locale
   * @return the city code provider
   */
  @NotNull
  public CityCodeProvider getProvider( @NotNull Locale locale ) {
    CityCodeProvider provider = codeProviders.get( locale.getCountry() );
    if ( provider == null ) {
      throw new IllegalArgumentException( "No provider registered for locale " + locale );
    }
    return provider;
  }
}
